OC.L10N.register(
    "documents",
    {
    "Documents" : "اسناد",
    "Can't create document" : "امکان ایجاد این سند وجود ندارد",
    "You don't have permission to rename this document" : "شما دسترسی مجاز برای تغییر نام این سند را ندارید",
    "Directory saved successfully." : "پوشه با موفقیت ذخیره شد.",
    "An error occurred while changing directory." : "یک خطا در حین تغییر پوشه رخ داده است.",
    "Saved" : "ذخیره شد",
    "Saving..." : "در حال ذخیره سازی...",
    "Failed to load documents." : "فراخوانی اسناد با شکست مواجه شد",
    "No documents were found. Upload or create a document to get started!" : "هیچ سندی یافت نشد. برای شروع سندی ساخته یا آپلود کنید! ",
    "No connection to server. Trying to reconnect." : "هیچگونه ارتباط به سرور موجود نمی‌باشد. لطفاً ارتباط مجدد برقرار کنید.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "خروج از این صفحه در مود ویرایش باعث از دست دادن اطلاعات ذخیر نشده خواهد شد. پیشنهاد می‌شود بجای آن که از دکمه‌ی 'خروج' استفاده فرمایید.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "فراخوانی این سند با مشکل مواجه شد. لطفاً بررسی نمایید که آیا می‌توان آن را با یک برنامه‌ی ویرایشگر odt خارجی باز نمود. البته این اشکال ممکن است بخاطر حذف شدن یا حذف اشتراک گذاری آن نیز اتفاق افتاده باشد",
    "Save" : "ذخیره",
    "Loading documents..." : "در حال بارگذاری اسناد...",
    "'.' is an invalid file name." : "'.'   یک نام پرونده نامعتبر است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "نام نامعتبر ،  '\\', '/', '<', '>', ':', '\"', '|', '?'  و '*'  مجاز نمی باشند.",
    "Align Left" : "چپ تراز",
    "Alignment" : "ترازکردن",
    "Align Right" : "راست تراز",
    "Annotate" : "حاشیه نگاری",
    "Background" : "پس زمینه",
    "Bold" : "ضخیم",
    "Bottom" : "پایین",
    "Cancel" : "منصرف شدن",
    "Center" : "وسط",
    "Clone" : "شبیه سازی",
    "Clone this Style" : "شبیه سازی این استایل",
    "Close" : "بستن",
    "Color" : "رنگ",
    "Create" : "ایجاد کردن",
    "Decrease Indent" : "کاهش تورفتگی",
    "Default Style" : "استایل پیشفرض",
    "Delete" : "حذف",
    "Family" : "خانواده",
    "Font" : "فونت",
    "Font Effects" : "افکت‌های فونت",
    "Format" : "فرمت",
    "Increase Indent" : "افزایش تورفتگی",
    "Insert Image" : "درج تصویر",
    "Invite Members" : "دعوت کردن اعضا",
    "Italic" : "کج نویس",
    "Justified" : "متقارن شد",
    "Justify" : "متقارن",
    "Left" : "چپ",
    "Loading" : "بارگذاری",
    "Members" : "اعضا",
    "New Name:" : "نام جدید:",
    "OK" : "باشه",
    "Open" : "باز کردن",
    "Options" : "تنظیمات",
    "Paragraph..." : "پاراگراف...",
    "Paragraph Styles" : "استایل های پاراگراف",
    "Redo" : "ازنو",
    "Right" : "راست",
    "Size" : "اندازه",
    "Spacing" : "فاصله گذاری",
    "Strikethrough" : "خط خورده",
    "Style" : "استایل",
    "Text" : "متن",
    "Top" : "ا",
    "Underline" : "خط زیرین",
    "Undo" : "بازگردان",
    "Unknown Author" : "نویسنده‌ی نامعلوم",
    "Shared" : "اشتراک گذاشته شده",
    "Error" : "خطا",
    "Error while sharing" : "خطا درحال به اشتراک گذاشتن",
    "Error while unsharing" : "خطا درحال لغو اشتراک",
    "Error while changing permissions" : "خطا در حال تغییر مجوز",
    "Shared with you and the group {group} by {owner}" : "به اشتراک گذاشته شده با شما و گروه {گروه} توسط {دارنده}",
    "Shared with you by {owner}" : "به اشتراک گذاشته شده با شما توسط { دارنده}",
    "Share with users or groups …" : "اشتراک گذاری با کاربران یا گروه ها ...",
    "Share with users, groups or remote users …" : "اشتراک گذاری با کاربران، گروه‌ها یا کاربران راه دور...",
    "Share" : "اشتراک‌گذاری",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "اشتراک‌گذاری با دیگر افراد بر روی ownClouds بصورت username@example.com/owncloud",
    "Share link" : "اشتراک گذاشتن لینک",
    "The public link will expire no later than {days} days after it is created" : "لینک عمومی پس از {days} روز پس از ایجاد منقضی خواهد شد",
    "Link" : "لینک",
    "Password protect" : "نگهداری کردن رمز عبور",
    "Password" : "گذرواژه",
    "Choose a password for the public link" : "انتخاب رمز برای لینک عمومی",
    "Allow editing" : "اجازه‌ی ویرایش",
    "Email link to person" : "پیوند ایمیل برای شخص.",
    "Send" : "ارسال",
    "Set expiration date" : "تنظیم تاریخ انقضا",
    "Expiration" : "تاریخ انقضا",
    "Expiration date" : "تاریخ انقضا",
    "An error occured. Please try again" : "یک خطا رخ داده است، لطفا مجددا تلاش کنید",
    "Adding user..." : "افزودن کاربر...",
    "group" : "گروه",
    "remote" : "از راه دور",
    "Resharing is not allowed" : "اشتراک گذاری مجدد مجاز نمی باشد",
    "Shared in {item} with {user}" : "به اشتراک گذاشته شده در {بخش} با {کاربر}",
    "Unshare" : "لغو اشتراک",
    "notify by email" : "دریافت هشدار از طریق ایمیل",
    "can share" : "قابل به اشتراک گذاری",
    "can edit" : "می توان ویرایش کرد",
    "access control" : "کنترل دسترسی",
    "create" : "ایجاد",
    "change" : "تغییر",
    "delete" : "پاک کردن",
    "Password protected" : "نگهداری از رمز عبور",
    "Error unsetting expiration date" : "خطا در تنظیم نکردن تاریخ انقضا ",
    "Error setting expiration date" : "خطا در تنظیم تاریخ انقضا",
    "Sending ..." : "درحال ارسال ...",
    "Email sent" : "ایمیل ارسال شد",
    "Warning" : "اخطار",
    "Edit" : "ویرایش",
    "guest" : "میهمان",
    "MS Word support (requires openOffice/libreOffice)" : "پشتیبانی از ماکروسافت ورد(نیازمند لیبره آفیس/ اپن آفیس)",
    "Local" : "محلی",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "اپن افیس/لیبره آفیس بر روی این سرور نصب شده اند. مسیر دسترسی به کد باینری از طریق preview_libreoffice_path in config.phpموجود می‌باشد. ",
    "External" : "خارجی",
    "Disabled" : "غیرفعال شده",
    "No MS Word support" : "عدم پشتیبانی از MS Word",
    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
    "Server URL" : "URL سرور",
    "Apply and test" : "اعمال و تست",
    "New document" : "سند جدید",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "Upload" : "بارگزاری",
    "Save new documents to" : "ذخیره کردن اسناد جدید به",
    "Wrong password. Please retry." : "رمز اشتباه. لطفاً مجددا تکرار فرمایید.",
    "Guest %s" : "میهمان %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "این لینک منقضی شده یا اینکه هرگز وجود نداشته است. لطفاً از کسی که آن را با شما به اشتراک گذاشته جزئیات را جویا شوید.",
    "Advanced feature-set" : "مجموعه‌ی امکانات پیشرفته",
    "(Unstable)" : "(ناپایدار)"
},
"nplurals=1; plural=0;");
